Learn R Programming

deadband (version 0.1.0)

deadbandAD: deadbandAD Function

Description

This function allows you to compute the Absolute Deadband(AD) algorithm

Usage

deadbandAD(x, EUmax, EUmin, d, offset)

Arguments

x
The vector of the samples before the deadband algorithm
EUmax
The Engineering Unit higher bound
EUmin
The Engineering Unit lower bound
d
Deadband percent parameter in range 0..1
offset
How many sample do you want skip at begin? Defaults is n=20

Value

A list containing the L2 distance and the Number of filtered samples

Examples

Run this code
deadbandAD(rnorm(40, mean = 0, sd = 1),+0.5,-0.5,0.01,20)

Run the code above in your browser using DataLab