Learn R Programming

deadband (version 0.1.0)

deadbandVD: deadbandVD Function

Description

This function allows you to compute the Volatility Deadband(VD) algorithm

Usage

deadbandVD(x, d, offset, k)

Arguments

x
The vector of the samples before the deadband algorithm
d
Deadband percent parameter in range 0..1
offset
How many sample do you want skip at begin? Defaults is n=20
k
multiplier used in Bollinger theory

Value

A list containing the L2 distance and the Number of filtered samples

Examples

Run this code
deadbandVD(rnorm(40, mean = 0, sd = 1),0.01,20,2)

Run the code above in your browser using DataLab